@@ -18,18 +18,19 @@ struct ltstring
   }
 };
 
-typedef MYSTD::map<mstring, mstring, ltstring> NoCaseStringMap;
+typedef MYMAP<mstring, mstring, ltstring> NoCaseStringMap;
 
 namespace acfg
 {
 
-extern mstring cachedir, logdir, confdir, fifopath, user, group, pidfile, 
+extern mstring cachedir, logdir, confdir, fifopath, user, group, pidfile, suppdir,
 reportpage, vfilepat, pfilepat, wfilepat, agentname, remoteport, adminauth, bindaddr, port, sUmask,
 tmpDontcacherq, tmpDontcachetgt, tmpDontcache, mirrorsrcs, requestapx;
 
 extern int debug, numcores, offlinemode, foreground, verbose, stupidfs, forcemanaged, keepnver,
-verboselog, extreshhold, exfailabort, tpstandbymax, tpthreadmax, dnscachetime, dlbufsize,
-exporigin, logxff, oldupdate, recompbz2, nettimeout, updinterval, forwardsoap, dirperms, fileperms;
+verboselog, extreshhold, exfailabort, tpstandbymax, tpthreadmax, dnscachetime, dlbufsize, usewrap,
+exporigin, logxff, oldupdate, recompbz2, nettimeout, updinterval, forwardsoap, dirperms, fileperms,
+maxtempdelay;
 
 // processed config settings
 extern tHttpUrl proxy_info;
