@@ -42,7 +42,8 @@ namespace aclog
       void transfer(char cLogType, uint64_t nCount, const char *szClient, const char *szPath);
       void err(const char *msg, const char *client=NULL);
       void misc(const mstring & sLine, const char cLogType='M');
-      inline void err(const mstring msg) { err(msg.c_str()); }
+      inline void err(cmstring &msg) { err(msg.c_str()); }
+      inline void err(const tSS& msg) { err(msg.c_str()); }
       void flush();
       
       void GenerateReport(mstring &);
@@ -69,7 +70,8 @@ namespace aclog
 
       mstring GetStatReport();
       
-      struct errnoFmter : public mstring {
+      struct errnoFmter : public mstring
+      {
     	  errnoFmter(const char *prefix=NULL);
       };
 }
