@@ -70,7 +70,7 @@ struct tFileNdir
 	}
 };
 
-typedef MYSTD::map<tFileNdir, tDiskFileInfo> tS2DAT;
+typedef MYMAP<tFileNdir, tDiskFileInfo> tS2DAT;
 
 struct tPatchEntry
 {
@@ -81,8 +81,8 @@ typedef deque<tPatchEntry>::const_iterator tPListConstIt;
 
 typedef MYSTD::pair<tFingerprint,mstring> tContId;
 struct tClassDesc {tStrDeq paths; tContId diffIdxId, bz2VersContId;};
-typedef MYSTD::map<tContId, tClassDesc> tContId2eqClass;
-typedef MYSTD::map<tContId, tClassDesc>::iterator tClassMapIter;
+typedef MYMAP<tContId, tClassDesc> tContId2eqClass;
+typedef MYMAP<tContId, tClassDesc>::iterator tClassMapIter;
 
 void DelTree(const string &what);
 
@@ -125,7 +125,7 @@ protected:
 		{};
 	};
 
-	typedef MYSTD::map<mstring,tIfileAttribs> tS2IDX;
+	typedef MYMAP<mstring,tIfileAttribs> tS2IDX;
 	tS2IDX m_indexFilesRel;
 	// helpers to keep the code cleaner and more readable
 	const tIfileAttribs &GetFlags(cmstring &sPathRel) const;
@@ -182,7 +182,7 @@ protected:
 	bool ParseAndProcessIndexFile(ifileprocessor &output_receiver,
 			const mstring &sPath, enumIndexType idxType);
 
-	MYSTD::map<mstring,bool> m_forcedTrashMap;
+	MYMAP<mstring,bool> m_forcedTrashMap;
 
 	bool GetAndCheckHead(cmstring & sHeadfile, cmstring &sFilePathRel, off_t nWantedSize);
 	bool Inject(cmstring &fromRel, cmstring &toRel,
@@ -201,6 +201,7 @@ protected:
 			m_nProgTell*=2;
 		}
 	}
+	void AddDelCbox(cmstring &sFileRel);
 
 private:
 	virtual void UpdateFingerprint(const mstring &sPathRel, off_t nOverrideSize,
