@@ -84,7 +84,7 @@ int getUUID();
 
 #define SPACECHARS " \f\n\r\t\v"
 
-typedef MYSTD::map<mstring, mstring> tStrMap;
+typedef MYMAP<mstring, mstring> tStrMap;
 
 inline void trimFront(mstring &s, const char *junk=SPACECHARS)
 {
@@ -247,7 +247,7 @@ mstring offttosH(off_t n);
 
 tStrDeq ExpandFilePattern(const mstring &pattern, bool bSorted=false);
 
-void MakeAbsolutePath(mstring &dirToFix, const mstring &reldir);
+//void MakeAbsolutePath(mstring &dirToFix, const mstring &reldir);
 
 
 void HttpEscape(mstring &s);
@@ -352,5 +352,7 @@ public:
 
 void DelTree(cmstring &what);
 
+bool IsAbsolute(cmstring &dirToFix);
+
 #endif // _META_H
 
