@@ -51,6 +51,7 @@ MapNameToString n2sTbl[] = {
 		{  "Port", 			&port , 0}
 		,{ "CacheDir", 	&cachedir, 0 }
 		,{ "LogDir", 	&logdir , 0}
+		,{ "SupportDir", 	&suppdir, 0}
 		,{ "SocketPath", 	&fifopath, 0}
 		,{ "PidFile", 	&pidfile, 0}
 		//,{ "Proxy",		&proxy, 0}
@@ -71,34 +72,36 @@ MapNameToString n2sTbl[] = {
 
 MapNameToInt n2iTbl[] = {
 		{ "Debug", 		&debug, 0 , 10}
-		,{ "OfflineMode", 	&offlinemode , 0, 10}
-		,{ "ForeGround", 	&foreground , 0, 10}
-		,{ "Verbose", 		0, "Option is deprecated, ignoring the value." , 10}
-		,{ "ForceManaged", 	&forcemanaged , 0, 10}
-		,{ "StupidFs", 		&stupidfs , 0, 10}
-		,{ "VerboseLog",	&verboselog , 0, 10}
-		,{ "ExTreshold",	&extreshhold, 0, 10}
+		,{ "OfflineMode", 	&offlinemode , NULL, 10}
+		,{ "ForeGround", 	&foreground , NULL, 10}
+		,{ "Verbose", 		NULL, "Option is deprecated, ignoring the value." , 10}
+		,{ "ForceManaged", 	&forcemanaged , NULL, 10}
+		,{ "StupidFs", 		&stupidfs , NULL, 10}
+		,{ "VerboseLog",	&verboselog , NULL, 10}
+		,{ "ExTreshold",	&extreshhold, NULL, 10}
 		,{ "MaxSpareThreadSets",	&tpstandbymax, "Deprecated option name, mapped to MaxStandbyConThreads", 10}
-		,{ "MaxStandbyConThreads",	&tpstandbymax, 0, 10}
-		,{ "MaxConThreads",	&tpthreadmax, 0, 10}
-		,{ "DnsCacheSeconds", &dnscachetime, 0, 10}
-		,{ "UnbufferLogs", &debug , 0, 10}
-		,{ "ExAbortOnProblems", &exfailabort, 0, 10}
-		,{ "ExposeOrigin", &exporigin, 0, 10}
-		,{ "LogSubmittedOrigin", &logxff, 0, 10}
+		,{ "MaxStandbyConThreads",	&tpstandbymax, NULL, 10}
+		,{ "MaxConThreads",	&tpthreadmax, NULL, 10}
+		,{ "DnsCacheSeconds", &dnscachetime, NULL, 10}
+		,{ "UnbufferLogs", &debug , NULL, 10}
+		,{ "ExAbortOnProblems", &exfailabort, NULL, 10}
+		,{ "ExposeOrigin", &exporigin, NULL, 10}
+		,{ "LogSubmittedOrigin", &logxff, NULL, 10}
 		,{ "OldIndexUpdater", &oldupdate, "Option is deprecated, ignoring the value." , 10}
-		,{ "RecompBz2", &recompbz2, 0, 10}
-		,{ "NetworkTimeout", &nettimeout, 0, 10}
-		,{ "MinUpdateInterval", &updinterval, 0, 10}
-		,{ "ForwardBtsSoap", &forwardsoap, 0, 10}
-		,{ "KeepExtraVersions", &keepnver, 0, 10}
+		,{ "RecompBz2", &recompbz2, NULL, 10}
+		,{ "NetworkTimeout", &nettimeout, NULL, 10}
+		,{ "MinUpdateInterval", &updinterval, NULL, 10}
+		,{ "ForwardBtsSoap", &forwardsoap, NULL, 10}
+		,{ "KeepExtraVersions", &keepnver, NULL, 10}
+		,{ "UseWrap", &usewrap, NULL, 10}
+		,{ "FreshIndexMaxAge", &maxtempdelay, NULL, 10}
 
-		,{ "DirPerms", &dirperms, 0, 8}
-		,{ "FilePerms", &fileperms, 0, 8}
+		,{ "DirPerms", &dirperms, NULL, 8}
+		,{ "FilePerms", &fileperms, NULL, 8}
 };
 
-void _ReadRewriteFiles(const string & sFile, const string & sRepName);
-void _ReadBackendsFiles(const string & sFile, const string &sRepName);
+void ReadRewriteFile(const string & sFile, const string & sRepName);
+void ReadBackendsFile(const string & sFile, const string &sRepName);
 
 
 
@@ -144,6 +147,40 @@ int * _GetIntPtr(const string &key, int &base) {
 	return NULL;
 }
 
+
+// shortcut for frequently needed code, opens the config file, reads step-by-step
+// and skips comment and empty lines
+struct tCfgIter
+{
+	filereader reader;
+	string sLine;
+	tCfgIter(cmstring &fn)
+	{
+		reader.OpenFile(fn);
+		reader.AddEofLines();
+	}
+	inline operator bool() const { return reader.CheckGoodState(false); }
+	inline bool Next()
+	{
+		while(reader.GetOneLine(sLine))
+		{
+			trimFront(sLine);
+			if(sLine.empty() || sLine[0] == '#')
+				continue;
+			return true;
+		}
+		return false;
+	}
+};
+
+inline bool qgrep(cmstring &needle, cmstring &file)
+{
+	for(acfg::tCfgIter itor(file); itor.Next();)
+		if(itor.sLine.find(needle) != stmiss)
+			return true;
+	return false;
+}
+
 inline void _FixPostPreSlashes(string &val)
 {
 	// fix broken entries
@@ -156,23 +193,19 @@ inline void _FixPostPreSlashes(string &val)
 
 inline bool _ReadMainConfiguration(const string & szFilename)
 {
-	filereader reader;
-	reader.OpenFile(szFilename);
-	reader.CheckGoodState(true);
-	string sLine;
-	while(reader.GetOneLine(sLine))
+	tCfgIter itor(szFilename);
+	itor.reader.CheckGoodState(true);
+	while(itor.Next())
 	{
-		trimFront(sLine);
-		if(sLine.empty() || sLine[0]=='#')
-			continue;
 #ifdef DEBUG
-		cerr << sLine <<endl;
+		cerr << itor.sLine <<endl;
 #endif
-		tStrPos pos=sLine.find('#');
+		// XXX: To something about escaped/quoted version
+		tStrPos pos=itor.sLine.find('#');
 		if(stmiss != pos)
-			sLine.erase(pos);
+			itor.sLine.erase(pos);
 
-		if(! SetOption(sLine))
+		if(! SetOption(itor.sLine))
 			BARF("Error reading main options, terminating.");
 	}
 	return true;
@@ -220,32 +253,6 @@ inline bool ParseOptionLine(const string &sLine, string &key, string &val, bool
 }
 
 
-
-struct tCfgIter
-{
-	filereader reader;
-	string sLine, key, val;
-	bool bIsOpen;
-	tCfgIter(cmstring &fn)
-	{
-		reader.OpenFile(fn);
-		reader.AddEofLines();
-		bIsOpen = reader.CheckGoodState(false);
-	}
-	inline bool Next(bool beQuiet)
-	{
-		while(reader.GetOneLine(sLine))
-		{
-			trimFront(sLine);
-			if(sLine.empty() || sLine[0] == '#')
-				continue;
-			if(ParseOptionLine(sLine, key, val, beQuiet))
-				return true;
-		}
-		return false;
-	}
-};
-
 inline void AddRemapFlag(const string & token, const string &repname)
 {
 	mstring key, value;
@@ -276,6 +283,54 @@ inline void AddRemapFlag(const string & token, const string &repname)
 	}
 }
 
+tStrDeq ExpandFileTokens(cmstring &token)
+{
+
+	tStrDeq srcs;
+
+	string sPath = token.substr(5);
+	if (sPath.empty())
+		BARF("Bad file spec for repname, file:?");
+	bool bAbs = IsAbsolute(sPath);
+	if (suppdir.empty() || bAbs)
+	{
+		if (!bAbs)
+			sPath = confdir + sPathSep + sPath;
+		srcs = ExpandFilePattern(sPath, true);
+	}
+	else
+	{
+		tStrMap bname2path;
+
+		mstring* paths[] =
+		{ &suppdir, &confdir };
+		for (mstring **ps = paths; ps < paths + _countof(paths); ++ps)
+		{
+			// chop slashes. That should not be required but better be sure.
+			while(endsWithSzAr(**ps, sPathSep) && (**ps).size()>1)
+				(**ps).resize((**ps).size()-1);
+
+			// temporary only
+			srcs = ExpandFilePattern(**ps + sPathSep + sPath, true);
+			if (srcs.size() == 1 && GetFileSize(srcs[0], -23) == off_t(-23))
+				continue; // file not existing, wildcard returned
+
+			// hits in confdir will overwrite those from suppdir
+			for (; !srcs.empty(); srcs.pop_back())
+				bname2path[::basename(srcs.back().c_str())] = srcs.back();
+		}
+		if (bname2path.empty())
+		{
+			cerr << "WARNING: No URL list file matching " << token
+					<< " found in config or support directories." << endl;
+		}
+		srcs.clear();
+		for (tStrMap::const_iterator it = bname2path.begin(); it != bname2path.end(); ++it)
+			srcs.push_back(it->second);
+	}
+	return srcs;
+}
+
 inline void AddRemapInfo(bool bAsBackend, const string & token,
 		const string &repname)
 {
@@ -297,19 +352,14 @@ inline void AddRemapInfo(bool bAsBackend, const string & token,
 	}
 	else
 	{
-		string sPath=token.substr(5);
-		if (sPath.empty())
-			BARF("Bad file spec for repname, file:?");
+		tStrDeq srcs = ExpandFileTokens(token);
 		
-		MakeAbsolutePath(sPath, confdir);
-		
-		tStrDeq srcs=ExpandFilePattern(sPath, true);
 		for(tStrDeq::const_iterator it=srcs.begin(); it!=srcs.end(); it++)
 		{
 			if (bAsBackend)
-				_ReadBackendsFiles(*it, repname);
+				ReadBackendsFile(*it, repname);
 			else
-				_ReadRewriteFiles(*it, repname);
+				ReadRewriteFile(*it, repname);
 		}
 	}
 }
@@ -351,25 +401,30 @@ struct tHookHandler: public tRepoData::IHookHandler, public lockable
 
 void _AddHooksFile(cmstring& vname)
 {
-	tCfgIter reader(acfg::confdir+"/"+vname+".hooks");
-	if(!reader.bIsOpen)
+	tCfgIter itor(acfg::confdir+"/"+vname+".hooks");
+	if(!itor)
 		return;
+
 	struct tHookHandler &hs = *(new tHookHandler(vname));
-	while (reader.Next(false))
+	mstring key,val;
+	while (itor.Next())
 	{
-		const char *p = reader.key.c_str();
+		if(!ParseOptionLine(itor.sLine, key, val, false))
+			continue;
+
+		const char *p = key.c_str();
 		if (strcasecmp("PreUp", p) == 0)
 		{
-			hs.cmdCon = reader.val;
+			hs.cmdCon = val;
 		}
 		else if (strcasecmp("Down", p) == 0)
 		{
-			hs.cmdRel = reader.val;
+			hs.cmdRel = val;
 		}
 		else if (strcasecmp("DownTimeout", p) == 0)
 		{
 			errno = 0;
-			uint n = strtoul(reader.val.c_str(), NULL, 10);
+			uint n = strtoul(val.c_str(), NULL, 10);
 			if (!errno)
 				hs.downDuration = n;
 		}
@@ -456,15 +511,12 @@ inline void _ParseLocalDirs(cmstring &value)
 
 inline void _FetchMimeTypes()
 {
-	filereader mreader;
-	string line;
-	if(!mreader.OpenFile("/etc/mime.types", true) || !mreader.CheckGoodState(false))
-		return;
-	mreader.AddEofLines();
-
-	while(mreader.GetOneLine(line))
+	for(tCfgIter itor("/etc/mime.types");itor.Next();)
 	{
-		tSplitWalk split(&line);
+		// # regular types:
+		// text/plain             asc txt text pot brf  # plain ascii files
+
+		tSplitWalk split(&itor.sLine);
 		if(!split.Next())
 			continue;
 
@@ -476,7 +528,7 @@ inline void _FetchMimeTypes()
 		{
 			mstring suf=split;
 			if(startsWithSz(suf, "#"))
-				continue;
+				break;
 			mimemap[suf] = mimetype;
 		}
 	}
@@ -657,38 +709,34 @@ const tRepoData * GetBackendVec(cmstring &vname)
 }
 
 
-void _ReadBackendsFiles(const string & sFile, const string &sRepName)
+void ReadBackendsFile(const string & sFile, const string &sRepName)
 {
 
 	int nAddCount=0;
-	string sLine, key, val;
+	string key, val;
 	tHttpUrl entry;
 
-	filereader reader;
-	reader.OpenFile(sFile.c_str());
-
+	tCfgIter itor(sFile);
 	if(debug>4)
 		cout << "Reading backend file: " << sFile <<endl;
-	if(!reader.CheckGoodState(false))
+
+	if(!itor)
 	{
 		if(debug>4)
 			cout << "No backend data found, file ignored."<<endl;
 		goto try_read_default;
 	}
 	
-	reader.AddEofLines();
-	
-	while(reader.GetOneLine(sLine))
+	while(itor.Next())
 	{
-		trimLine(sLine);
-		//if(debug)
-		//	cerr << "backends, got line: " << sLine <<endl;
+		if(debug)
+			cerr << "backends, got line: " << itor.sLine <<endl;
 		
 		// either a URL line or the termination line and hostname/path have been set before
 
-		if( (startsWithSz(sLine, "http://") && entry.SetHttpUrl(sLine) )
+		if( (startsWithSz(itor.sLine, "http://") && entry.SetHttpUrl(itor.sLine) )
 				||
-			( sLine.empty()	&& ! entry.sHost.empty() && ! entry.sPath.empty()
+			( itor.sLine.empty() && ! entry.sHost.empty() && ! entry.sPath.empty()
 			)
 		)
 		{
@@ -704,7 +752,7 @@ void _ReadBackendsFiles(const string & sFile, const string &sRepName)
 			nAddCount++;
 			entry.clear();
 		}
-		else if(ParseKeyValLine(sLine, key, val))
+		else if(ParseKeyValLine(itor.sLine, key, val))
 		{
 			if(keyEq("Site", key))
 				entry.sHost=val;
@@ -727,10 +775,10 @@ void _ReadBackendsFiles(const string & sFile, const string &sRepName)
 				entry.sPath=val;
 			}
 		}
-		else if(!sLine.empty() && '#' != sLine[0])
+		else
 		{
 			cerr << "Bad backend description, around line "
-					<< reader.GetPositionDescription() << endl;
+					<< itor.reader.GetPositionDescription() << endl;
 			exit(2);
 		}
 	}
@@ -740,7 +788,7 @@ try_read_default:
 		return;
 	if(debug>4)
 		cout << "Trying to read replacement from " << sFile << ".default" <<endl;
-	_ReadBackendsFiles(sFile+".default", sRepName);
+	ReadBackendsFile(sFile+".default", sRepName);
 
 }
 
@@ -750,7 +798,7 @@ void ShutDown()
 	repoparms.clear();
 }
 
-void _ReadRewriteFiles(const string & sFile, const string & sRepName)
+void ReadRewriteFile(const string & sFile, const string & sRepName)
 {
 
 	filereader reader;
@@ -1007,11 +1055,26 @@ void PostProcConfig()
 	   }
    }
 
-   if (acfg::debug>=LOG_MORE)
+   if(usewrap == RESERVED_DEFVAL)
+   {
+	   usewrap=(qgrep("apt-cacher-ng", "/etc/hosts.deny")
+			   || qgrep("apt-cacher-ng", "/etc/hosts.allow"));
+#ifndef HAVE_LIBWRAP
+	   cerr << "Warning: configured to use libwrap filters but feature is not built-in." <<endl;
+#endif
+   }
+
+   if(maxtempdelay<0)
+   {
+	   cerr << "Invalid maxtempdelay value, using default" <<endl;
+	   maxtempdelay=27;
+   }
+
+   if (acfg::debug >= LOG_MORE)
 	{
-		for (UINT i=0; i<_countof(n2sTbl); i++)
-			if(n2sTbl[i].ptr)
-				cout << n2sTbl[i].name << " = " << *(n2sTbl[i].ptr) <<endl;
+		for (UINT i = 0; i < _countof(n2sTbl); i++)
+			if (n2sTbl[i].ptr)
+				cout << n2sTbl[i].name << " = " << *(n2sTbl[i].ptr) << endl;
 
 		if (acfg::debug >= LOG_DEBUG)
 		{
@@ -1021,16 +1084,16 @@ void PostProcConfig()
 				{
 					cout << n2sTbl[i].name << " = ";
 					for (const char *p = n2sTbl[i].ptr->c_str(); *p; p++)
-						if('\\' == *p)
+						if ('\\' == *p)
 							cout << "\\\\";
 						else
 							cout << *p;
-					cout <<endl;
+					cout << endl;
 				}
 		}
 
-		for (UINT i=0; i<_countof(n2iTbl); i++)
-			if(n2iTbl[i].ptr)
+		for (UINT i = 0; i < _countof(n2iTbl); i++)
+			if (n2iTbl[i].ptr)
 				cout << n2iTbl[i].name << " = \"" << *(n2iTbl[i].ptr) << "\"\n";
 	}
 
@@ -1135,7 +1198,7 @@ bool CompileExpressions()
 			char buf[1024];
 			regerror(nErr,  &rex[i], buf, sizeof(buf));
 			buf[_countof(buf)-1]=0; // better be safe...
-			std::cerr << buf << ": " << *(psRex[i]) << std::endl;
+			MYSTD::cerr << buf << ": " << *(psRex[i]) << MYSTD::endl;
 			return false;
 		}
 	}
@@ -1177,28 +1240,22 @@ inline bool CompileUncachedRex(const string & token, bool bIsTgtPattern, bool bR
 	}
 	else if(!bRecursiveCall) // don't go further than one level
 	{
-		string sPath=token.substr(5);
-		if (sPath.empty())
-			BARF("Bad file spec for repname, file:?");
-
-		MakeAbsolutePath(sPath, acfg::confdir);
-
-		tStrDeq srcs = ExpandFilePattern(sPath, true);
+		tStrDeq srcs = acfg::ExpandFileTokens(token);
 		for(tStrDeq::const_iterator it=srcs.begin(); it!=srcs.end(); it++)
 		{
-			filereader reader;
-			if(!reader.OpenFile(*it))
+			acfg::tCfgIter itor(*it);
+			if(!itor)
 			{
 				cerr << "Error opening pattern file: " << *it <<endl;
 				return false;
 			}
-			string line;
-			while(reader.GetOneLine(line))
+			while(itor.Next())
 			{
-				if(!CompileUncachedRex(*it, bIsTgtPattern, true))
+				if(!CompileUncachedRex(itor.sLine, bIsTgtPattern, true))
 					return false;
 			}
 		}
+
 		return true;
 	}
 
@@ -1277,6 +1334,7 @@ void mkbasedir(const string & path)
 }
 
 
+
 /*
 int main(int argc, char **argv)
 {
