@@ -17,10 +17,8 @@ namespace acfg {
 #define INFOLDER "(^|.*?/)"
 #endif
 
-
-// always the same
 string cachedir("/var/tmp"), logdir("/var/tmp"), fifopath, pidfile, reportpage,
-confdir, adminauth, bindaddr, mirrorsrcs;
+confdir, adminauth, bindaddr, mirrorsrcs, suppdir("/usr/lib/apt-cacher-ng");
 
 #define COMPRLIST "(\\.gz|\\.bz2|\\.lzma|\\.xz)"
 #define COMPONENT_OPTIONAL "(-[a-z0-9-])"
@@ -36,15 +34,16 @@ string pfilepat(".*(\\.d?deb|\\.rpm|\\.dsc|\\.tar"COMPRLIST"(\\.gpg)?"
 
 string vfilepat( INFOLDER
 		"(Index|Packages"COMPRLIST"?|InRelease|Release|Release\\.gpg|"
-		"Sources"COMPRLIST"?|release|index\\.db-.*\\.gz|Contents-[^/]*"COMPRLIST
-		"|pkglist[^/]*\\.bz2|rclist[^/]*\\.bz2|/meta-release[^/]*|Translation[^/]*"COMPRLIST
+		"Sources"COMPRLIST"?|release|index\\.db-.*\\.gz|Contents-[^/]*"COMPRLIST"?"
+		"|pkglist[^/]*\\.bz2|rclist[^/]*\\.bz2|/meta-release[^/]*|Translation[^/]*"COMPRLIST"?"
 		"|MD5SUMS|SHA1SUMS" // d-i stuff
 		"|((setup|setup-legacy)(\\.ini|\\.bz2|\\.hint)(\\.sig)?)|mirrors\\.lst" // cygwin
 		"|repo(index|md)\\.xml(\\.asc|\\.key)?|directory\\.yast" // opensuse
 		"|products|content(\\.asc|\\.key)?|media" // opensuse 2, are they important?
+		"|filelists\\.xml\\.gz|filelists\\.sqlite\\.bz2|repomd\\.xml" // SL, http://ra.khe.sh/computers/linux/apt-cacher-ng-with-yum.html
 		"|packages\\.[a-zA-Z][a-zA-Z]\\.gz|info\\.txt|license\\.tar\\.gz|license\\.zip" //opensuse
 		"|.*\\.db\\.tar\\.gz|.*\\.files\\.tar\\.gz|.*\\.abs\\.tar\\.gz" // Arch Linux
-//    "|metalink\\?repo"     "|.*prestodelta\\.xml\\.gz" // fedora core 13, worked in the beginning and then decided to hate me
+		"|metalink\\?repo|.*prestodelta\\.xml\\.gz" // fedora core, maybe... never worked reliably
 		")$" // end of filename paterns. Any other some specific URLs?
 		"|/dists/.*/installer-[^/]+/[^0-9][^/]+/images/.*"); // d-i stuff but not containing a number (year) in the revision directory (like "current", "beta", ...)
 
@@ -53,7 +52,7 @@ string vfilepat( INFOLDER
 string wfilepat(INFOLDER
 		"(Release|InRelease|Release\\.gpg"
 		"|(Packages|Sources)"COMPRLIST"?"
-		"|Translation[^/]*"COMPRLIST // to be checked, but they should never really go anywhere
+		"|Translation[^/]*"COMPRLIST"?" // to be checked, but they should never really go anywhere
 		"|MD5SUMS|SHA1SUMS"
 		"|.*\\.xml" // SUSE
 		"|.*\\.db\\.tar\\.gz|.*\\.files\\.tar\\.gz|.*\\.abs\\.tar\\.gz" // Arch Linux
@@ -64,10 +63,11 @@ string wfilepat(INFOLDER
 
 int offlinemode(false), verboselog(true), stupidfs(false), forcemanaged(false),
 extreshhold(20), tpstandbymax(8), tpthreadmax(-1), dirperms(00755), fileperms(00664),
-keepnver(0);
+keepnver(0), maxtempdelay(27);
 
 int dnscachetime(1800), dlbufsize(70000), exfailabort(1), exporigin(false), numcores(1),
-logxff(false), oldupdate(false), recompbz2(false), nettimeout(60), updinterval(0), forwardsoap(RESERVED_DEFVAL);
+logxff(false), oldupdate(false), recompbz2(false), nettimeout(60), updinterval(0),
+forwardsoap(RESERVED_DEFVAL), usewrap(RESERVED_DEFVAL);
 
 string agentname("Debian Apt-Cacher-NG/" ACVERSION);
 string remoteport("80"), port("3142");
