@@ -421,9 +421,7 @@ bool tCacheMan::Download(const MYSTD::string & sFilePathRel, bool bIndexFile,
 		}
 
 		if(nVerbosity == VERB_SHOW)
-			SendFmt() << "<label><input type=\"checkbox\" name=\"kf"
-			<< (nKillLfd++) << "\" value=\"" << sFilePathRel
-			<< "\">Tag</label>";
+			AddDelCbox(sFilePathRel);
 	}
 
 	if(nVerbosity!=VERB_QUIET)
@@ -1876,11 +1874,8 @@ void tCacheMan::_ProcessSeenIndexFiles()
 			{
 				m_nErrorCount++;
 				SendChunk("<font color=red>An error occured while reading this file, some contents may have been ignored.</font>\n");
-
-				SendFmt() << "<label><input type=\"checkbox\" name=\"kf"
-						<< (nKillLfd++) << "\" value=\"" << it->first
-						<< "\">Tag</label><br>\n";
-				m_bShowControls=true;
+				AddDelCbox(it->first);
+				SendChunk("<br>\n");
 			}
 			continue;
 		}
@@ -1897,6 +1892,13 @@ void tCacheMan::_ProcessSeenIndexFiles()
 	}
 }
 
+void tCacheMan::AddDelCbox(cmstring &sFileRel)
+{
+	m_bShowControls=true;
+	SendFmt() << "<label><input type=\"checkbox\" name=\"kf" << (nKillLfd++)
+			<< "\" value=\"" << sFileRel << "\">Tag</label>";
+
+}
 void tCacheMan::TellCount(uint nCount, off_t nSize)
 {
 	SendFmt() << "<br>\n" << nCount <<" package file(s) marked "
