@@ -267,7 +267,7 @@ struct tDlJob
 				return EFLAG_MORE;
 			else if (l > 0)
 			{
-				ldbg("contents: " << std::string(inBuf.rptr(), l));
+				ldbg("contents: " << MYSTD::string(inBuf.rptr(), l));
 				inBuf.drop(l);
 				if (h.type != header::ANSWER)
 				{
@@ -434,7 +434,7 @@ inline bool dlcon::SetupJobConfig(tDlJobPtr &job, mstring *pReasonMsg)
 	LOGSTART("dlcon::SetupJobConfig");
 	// using backends? Find one which is not blacklisted
 
-	MYSTD::map<MYSTD::pair<cmstring,cmstring>, mstring>::const_iterator bliter;
+	MYMAP<MYSTD::pair<cmstring,cmstring>, mstring>::const_iterator bliter;
 
 	if (job->m_pBEdata)
 	{
@@ -543,7 +543,7 @@ inline UINT dlcon::ExchangeData(mstring &sErrorMsg, int fd, tDljQueue &qActive)
 		if (fd>=0)
 		{
 			FD_SET(fd, &rfds);
-			nMaxFd = std::max(fd, nMaxFd);
+			nMaxFd = MYSTD::max(fd, nMaxFd);
 
 			if (!m_sendBuf.empty())
 			{
