@@ -32,6 +32,9 @@ using namespace MYSTD;
 #define TIMEEXPIRED(t) (t < (m_gMaintTimeNow-acfg::extreshhold*86400))
 #define TIME_AGONY (m_gMaintTimeNow-acfg::extreshhold*86400)
 
+#define FNAME_PENDING "_expending_dat"
+#define FNAME_DAMAGED "_expending_damaged"
+
 void expiration::HandlePkgEntry(const tRemoteFileInfo &entry, bool bUnpackForCsumming)
 {
 	LOGSTART2("expiration::_HandlePkgEntry:",
@@ -43,6 +46,7 @@ void expiration::HandlePkgEntry(const tRemoteFileInfo &entry, bool bUnpackForCsu
 	// debian-installer files also need to do path checks
 	// checksum mode also needs to be sure about path in order to not display false positives to the user
 
+	// cannot use equal_range() without directory consideration, skip equal entries manually
 	tFileNdir startHook(entry.sFileName, m_bNeedsStrictPathsHere ? entry.sDirectory : "");
 	for(tS2DAT::iterator it=m_trashCandSet.lower_bound(startHook);
 			it!=m_trashCandSet.end();
@@ -50,7 +54,7 @@ void expiration::HandlePkgEntry(const tRemoteFileInfo &entry, bool bUnpackForCsu
 	{
 		const tFileNdir &k = it->first; // shortcut
 
-		// where are we, still at the right filename?
+		// where are we, still at the right filename? or could use range instead of lower_bound...
 		if(entry.sFileName != k.file)
 			return;
 
@@ -136,34 +140,62 @@ void expiration::HandlePkgEntry(const tRemoteFileInfo &entry, bool bUnpackForCsu
 
 		if(m_bByChecksum)
 		{
+
 			bool bSkipDataCheck=false;
 
-			// scan file if not done before or the checksum type differs
-			if(fprNeed.csType != fprHave.csType)
+			// can tell this early with information form dirscan if unpacking is not needed
+			if(!bUnpackForCsumming && fprHave.size < entry.fpr.size)
 			{
-				if(!fprHave.ScanFile(sPathAbs, fprNeed.csType, bUnpackForCsumming))
-				{
-					// IO error? better keep it for now
-					aclog::err(string("An error occured while checksumming ")
-							+sPathAbs+", not touching it.");
-					bSkipDataCheck=true;
-				}
+				if(m_bIncompleteIsDamaged)
+					goto l_tell_damaged;
+				else
+					goto l_tell_incomplete;
 			}
 
-			if ( !bSkipDataCheck)
+			// scan file if not done before or the checksum type differs
+			if(fprNeed.csType != fprHave.csType
+					&& !fprHave.ScanFile(sPathAbs, fprNeed.csType, bUnpackForCsumming))
 			{
-				if ( ! (fprHave == entry.fpr))
+					// IO error? better keep it for now
+				aclog::err(tSS()<<"An error occurred while checksumming "
+						<< sPathAbs	<< ", not touching it.");
+				bSkipDataCheck=true;
+			}
+
+			if ( !bSkipDataCheck && fprHave != entry.fpr)
+			{
+				if (fprHave.size < entry.fpr.size && !m_bIncompleteIsDamaged)
 				{
-					if(m_bTruncateDamaged)
+					l_tell_incomplete:
+					SendFmt() << "<font color=orange>INCOMPLETE: " << sPathRel
+							<< " (ignoring)</font><br>\n";
+				}
+				else if (m_bTruncateDamaged)
+				{
+					SendFmt() << "<font color=orange>BAD: " << sPathRel
+							<< " (truncating)</font><br>\n";
+					::truncate(sPathAbs.c_str(), 0);
+				}
+				else
+				{
+					l_tell_damaged:
+
+					if(GetFlags(sPathRel).parseignore)
 					{
-						SendFmt()<<"<font color=orange>BAD: "<<sPathAbs<<" (truncating)</font><br>\n";
-						::truncate(sPathAbs.c_str(), 0);
+						SendFmt() << sPathRel << ": incorrect or obsolete contents but marked as "
+								"alternative version of another index file (ignoring)";
 					}
 					else
 					{
-						SendFmt()<<"<font color=red>BAD: "<<sPathAbs<<"</font><br>\n";
-						goto keep_in_trash;
+						if (m_damageList.is_open())
+							m_damageList << sPathRel << endl;
+						SendFmt() << "<font color=red>BAD: " << sPathRel
+								<< " (adding to damage list)</font>";
+						AddDelCbox(sPathRel);
 					}
+					SendChunk("<br>\n");
+
+					goto keep_in_trash;
 				}
 			}
 		}
@@ -275,7 +307,8 @@ inline void expiration::DropExceptionalVersions()
 		pkgGroup.insert(key);
 	}
 	if(ec)
-		SendFmt() << "Kept " << ec << " more package(s) not covered by index references<br>\n";
+		SendFmt() << "<br><b>Kept "
+		<< ec << " more package(s) not covered by index references</b><br><br>\n";
 }
 
 inline void expiration::RemoveAndStoreStatus(bool bPurgeNow)
@@ -392,13 +425,13 @@ inline void expiration::RemoveAndStoreStatus(bool bPurgeNow)
 
 void expiration::Action(const string & cmd)
 {
-	if (cmd.find("justRemove")!=stmiss)
+	if (m_mode==purge)
 	{
 		LoadTrashMapFromFile(true);
 		RemoveAndStoreStatus(true);
 		return;
 	}
-	if (cmd.find("justShow")!=stmiss)
+	if (m_mode==list)
 	{
 		LoadTrashMapFromFile(true);
 		off_t nSpace(0);
@@ -424,11 +457,38 @@ void expiration::Action(const string & cmd)
 			}
 		}
 		TellCount(cnt, nSpace);
+
+		mstring delURL(cmd);
+		StrSubst(delURL, "justShow", "justRemove");
+		SendFmt() << "<a href=\"/"<<delURL<<"\">Delete all listed files</a> "
+				"(no further confirmation)<br>\n";
+		return;
+	}
+	if(m_mode==purgeDamaged || m_mode==listDamaged)
+	{
+		filereader f;
+		if(!f.OpenFile(SABSPATH(FNAME_DAMAGED)))
+		{
+			SendChunk("List of damaged files not found");
+			return;
+		}
+		mstring s;
+		while(f.GetOneLine(s))
+		{
+			SendFmt() << (m_mode==purgeDamaged ? "Removing " : "") << s << "<br>\n";
+			if(m_mode==purgeDamaged)
+			{
+				::unlink(SZABSPATH(s));
+				::unlink(SZABSPATH(s+".head"));
+			}
+		}
 		return;
 	}
 
 	SetCommonUserFlags(cmd);
 
+	m_bIncompleteIsDamaged=(cmd.find("incomAsDamaged")!=stmiss);
+
 	SendChunk("<b>Locating potentially expired files in the cache...</b><br>\n");
 
 	DirectoryWalk(acfg::cachedir, this);
@@ -453,6 +513,7 @@ void expiration::Action(const string & cmd)
 		return;
 	}
 
+	m_damageList.open(SZABSPATH(FNAME_DAMAGED), ios::out | ios::trunc);
 
 	SendChunk("<b>Validating cache contents...</b><br>\n");
 	_ProcessSeenIndexFiles();
@@ -553,6 +614,10 @@ bool expiration::ProcessRegular(const string & sPathAbs, const struct stat &stin
 
 	string sPathRel(sPathAbs, CACHE_BASE_LEN);
 
+	// detect strings which are only useful for shell or js attacks
+	if(sPathRel.find_first_of("\r\n'\"<>")!=stmiss)
+		return true;
+
 	if(sPathRel[0] == '_' && !m_bScanInternals)
 		return true; // not for us
 
@@ -562,7 +627,7 @@ bool expiration::ProcessRegular(const string & sPathAbs, const struct stat &stin
 	else
 	{
 		AddIFileCandidate(sPathRel);
-#warning TODO: when Lenny is history, add additional MD5SUMS file to the list for d-i image files
+//#warning TODO: when Lenny is history, add additional MD5SUMS file to the list for d-i image files
 		//SendChunk(string("<br>hm?<br>")+sDirnameAndSlash + " -- " + sBasename);
 		tDiskFileInfo &finfo = m_trashCandSet[sPathRel];
 		finfo.nLostAt = m_gMaintTimeNow;
@@ -572,9 +637,17 @@ bool expiration::ProcessRegular(const string & sPathAbs, const struct stat &stin
 }
 
 
-expiration::expiration(int fd) : tCacheMan(fd)
+expiration::expiration(int fd, workType type) : tCacheMan(fd), m_mode(type)
 {
-	m_sTypeName="Expiration";
+	switch(type)
+	{
+	case list: m_sTypeName="Listing unreferenced"; break;
+	case listDamaged: m_sTypeName="Listing damaged files"; break;
+	case purgeDamaged: m_sTypeName="Removing damaged files"; break;
+	case expire:
+	default:
+		m_sTypeName="Expiration"; break;
+	}
 }
 
 expiration::~expiration()
@@ -585,7 +658,10 @@ void expiration::LoadIgnoreList()
 {
 	filereader reader;
 	if(!reader.OpenFile(acfg::confdir+SZPATHSEP+"ignore_list"))
-		return;
+	{
+		if(acfg::suppdir.empty() || !reader.OpenFile(acfg::suppdir+SZPATHSEP+"ignore_list"))
+				return;
+	}
 	string sTmp;
 	while (reader.GetOneLine(sTmp))
 	{
@@ -599,9 +675,8 @@ void expiration::LoadIgnoreList()
 }
 void expiration::LoadTrashMapFromFile(bool bForceInsert)
 {
-
 	filereader reader;
-	reader.OpenFile(CACHE_BASE+"_expending_dat");
+	reader.OpenFile(SABSPATH(FNAME_PENDING));
 
 	string sLine;
 
