@@ -15,7 +15,7 @@
 
 using namespace MYSTD;
 
-#define MAXTEMPDELAY 27
+#define MAXTEMPDELAY acfg::maxtempdelay // 27
 
 header const & fileitem::GetHeaderUnlocked()
 {
@@ -586,7 +586,7 @@ struct tFileRefEntry
 	bool m_bNeedsDelayedExpiration;
 	tFileRefEntry() : nRefCount(0), m_bNeedsDelayedExpiration(false) { };
 };
-static map<string, tFileRefEntry> mapItems;
+static MYMAP<string, tFileRefEntry> mapItems;
 lockable mapLck;
 
 void fileitem::Unreg()
@@ -595,7 +595,7 @@ void fileitem::Unreg()
 
    lockguard managementLock(mapLck); 
 	
-   std::map<string,tFileRefEntry>::iterator entry = mapItems.find(m_sPathRel);
+   MYMAP<string,tFileRefEntry>::iterator entry = mapItems.find(m_sPathRel);
    if(mapItems.end() == entry)
    {
 	   aclog::err("INTERNAL ERROR, attempt to unregister non-existing download item");
@@ -685,7 +685,7 @@ void fileitem::UnregOneASAP(tFileItemPtr pItem)
 		return;
 	}
 	lockguard lockGlobalMap(mapLck);
-	std::map<string, tFileRefEntry>::iterator entry = mapItems.find(pItem->m_sPathRel);
+	MYMAP<string, tFileRefEntry>::iterator entry = mapItems.find(pItem->m_sPathRel);
 	// not existing? -> not for us. Still enough references? -> let this one go
 	if (mapItems.end() == entry || entry->second.nRefCount>1)
 	{
@@ -707,7 +707,7 @@ void fileitem::UnregOneASAP(tFileItemPtr pItem)
 time_t fileitem::DoDelayedUnregAndCheck()
 {
 	lockguard lockGlobalMap(mapLck);
-	std::map<string, tFileRefEntry>::iterator it, here;
+	MYMAP<string, tFileRefEntry>::iterator it, here;
 
 	time_t now=time(0);
 
