@@ -394,7 +394,7 @@ inline void job::HandleLocalDownload(const string &visPath,
 		else
 		{
 			// quick hack, good enough
-			MYSTD::map<string, tSS> sortMap;
+			tStrMap sortMap;
 			for(struct dirent dp, *pEndTest;
 					0==readdir_r(dir, &dp, &pEndTest) && pEndTest; )
 			{
@@ -408,7 +408,7 @@ inline void job::HandleLocalDownload(const string &visPath,
 				strftime(datestr, sizeof(datestr)-1,
 						"%d-%b-%Y %H:%M", localtime_r(&stbuf.st_mtime, &tmtimebuf));
 
-				tSS &line = sortMap[string(bDir?"a":"b")+dp.d_name];
+				tSS line;
 				if(bDir)
 					line << "[DIR]";
 				else if(startsWithSz(GetMimeType(dp.d_name), "image/"))
@@ -421,9 +421,10 @@ inline void job::HandleLocalDownload(const string &visPath,
 					line << "-";
 				else
 					line << offttosH(stbuf.st_size);
+				sortMap[string(bDir?"a":"b")+dp.d_name] = line;
 			}
 			closedir(dir);
-			for(MYSTD::map<string, tSS>::const_iterator it=sortMap.begin(); it!=sortMap.end(); it++)
+			for(tStrMap::const_iterator it=sortMap.begin(); it!=sortMap.end(); it++)
 				page << "<tr><td valign=\"top\">" << it->second << "</td></tr>\r\n";
 		}
 		page << "<tr><td colspan=\"4\">";
@@ -668,8 +669,8 @@ report_overload:
     return ;
 
 report_notallowed:
-	SetErrorResponse("403 Forbidden file type or location");
-    USRDBG(5, sRawUriPath + " -- ACCESS FORBIDDEN");
+	SetErrorResponse((tSS() << "403 Forbidden file type or location: " << sRawUriPath).c_str());
+//    USRDBG(5, sRawUriPath + " -- ACCESS FORBIDDEN");
     return ;
 
 report_offlineconf:
