@@ -309,7 +309,7 @@ void pkgimport::Action(const string &cmd)
 
 void pkgimport::HandlePkgEntry(const tRemoteFileInfo &entry, bool)
 {
-	//typedef MYSTD::map<tFingerprint, tImpFileInfo, ltfingerprint> tImportMap;
+	//typedef MYMAP<tFingerprint, tImpFileInfo, ltfingerprint> tImportMap;
 	tImportMap::iterator hit = m_importMap.find(entry.fpr);
 	if (hit==m_importMap.end())
 		return;
@@ -379,7 +379,7 @@ void pkgimport::HandlePkgEntry(const tRemoteFileInfo &entry, bool)
 
 void pkgimport::_LoadKeyCache(const string & sFileName)
 {
-	std::ifstream in;
+	MYSTD::ifstream in;
 
 	tImpFileInfo info;
 	tFingerprint fpr;
@@ -389,7 +389,7 @@ void pkgimport::_LoadKeyCache(const string & sFileName)
 	if(!in.is_open())
 		return;
 
-	std::getline(in, cs);
+	MYSTD::getline(in, cs);
 	if(cs!=FMTSIG)
 		return;
 
@@ -404,19 +404,19 @@ void pkgimport::_LoadKeyCache(const string & sFileName)
 		info.bFileUsed=false;
 
 		in>>sz;
-		std::getline(in, cs); // newline
+		MYSTD::getline(in, cs); // newline
 
 		in>>csType;
-		std::getline(in, cs); // newline
+		MYSTD::getline(in, cs); // newline
 
-		std::getline(in, cs); // checksum line
+		MYSTD::getline(in, cs); // checksum line
 		fpr.Set(cs, (CSTYPES)csType, sz);
 
-		std::getline(in, info.sPath);
+		MYSTD::getline(in, info.sPath);
 		info.sPath.insert(0, m_sSrcPath+SZPATHSEP);
 
 		in>>info.mtime;
-		std::getline(in, cs); // newline
+		MYSTD::getline(in, cs); // newline
 
 #ifdef DEBUG
 		bool bNix=(stmiss != info.sPath.find("cabextract"));
